==> dschaerf-extensions-3.38.9.tar.xz: dschaerf-extensions-3.38.9/README.md <==
# DSchaerf Extensions

DSchaerf Extensions is a collection of extensions providing additional
and optional functionality to GNOME Shell.

DSchaerf Extensions are compatible with GNOME Shell version 3.38.

For more information about [DSchaerf Extensions][project-page].

## Extensions

### legacyTray@extensions.dschaerf.de
 
Displays status icons in the lower left corner of the screen.

### panelManager@extensions.dschaerf.de

Contains useful extensions and settings for the GNOME Shell.
- add alternative display mode for Activities button
- add Applications menu button to GNOME Shell Panel (left side)
- add Places menu button to GNOME Shell Panel (left side)
- add Favorites menu button to GNOME Shell Panel (left side)
- add ShowDesktop button to GNOME Shell Panel (left side)
- add Trash menu button to GNOME Shell Panel (right side)
- add Input and Output device submenu items to Aggregate menu
- add Settings for PanelManager menu item to Aggregate menu
- add Teminal menu item to Aggregate menu
- add BasicSettings submenu item to Aggregate menu
- add Hibernate and Hybrid-Sleep menu item to Aggregate menu
- include multiple settings for PanelManager and GNOME Shell Panel

### temperature@extensions.dschaerf.de

Show temperatures for CPU and CPU cores, Hard disks drive and Graphics cards
in GNOME Shell panel.

## License

DSchaerf Extensions are distributed under the terms of the GNU General Public
License, version 2 or later. See the [COPYING file][license] for details.

[project-page]: https://extensions.dschaerf.de
[license]: COPYING

==> dschaerf-extensions_43.5.orig.tar.xz: dschaerf-extensions-43.5/README.md <==
# DSchaerf Extensions

DSchaerf Extensions is a collection of extensions providing additional
and optional functionality to GNOME Shell.

DSchaerf Extensions are compatible with GNOME Shell version 43.

For more information about [DSchaerf Extensions][project-page].

## Extensions

### legacyTray@extensions.dschaerf.de
 
Displays status icons in the lower left corner of the screen.

### panelManager@extensions.dschaerf.de

Contains useful extensions and settings for the GNOME Shell.
- add alternative display mode for Activities button
- add Applications menu button to GNOME Shell Panel (left side)
- add Places menu button to GNOME Shell Panel (left side)
- add Favorites menu button to GNOME Shell Panel (left side)
- add ShowDesktop button to GNOME Shell Panel (left side)
- add Trash menu button to GNOME Shell Panel (right side)
- add Settings for PanelManager button to QuickSettings menu
- add Terminal button to QuickSettings menu
- add Hibernate and Hybrid Sleep menu item to QuickSettings ShutDown menu
- add BasicSettings submenu to QuickSettings menu
- include multiple settings for PanelManager and GNOME Shell Panel

### temperature@extensions.dschaerf.de

Show temperatures for CPU and CPU cores, Hard disks drive and Graphics cards
in GNOME Shell panel.

## License

DSchaerf Extensions are distributed under the terms of the GNU General Public
License, version 2 or later. See the [COPYING file][license] for details.

[project-page]: https://extensions.dschaerf.de
[license]: COPYING
